# terraform-aws-eks-argocd

[![Lint Status](https://github.com/DNXLabs/terraform-aws-eks-argocd/workflows/Lint/badge.svg)](https://github.com/DNXLabs/terraform-aws-eks-argocd/actions)
[![LICENSE](https://img.shields.io/github/license/DNXLabs/terraform-aws-eks-argocd)](https://github.com/DNXLabs/terraform-aws-eks-argocd/blob/master/LICENSE)


Terraform module for deploying Kubernetes [Argo CD](https://argoproj.github.io/argo-cd/) and [Argo Rollouts](https://argoproj.github.io/argo-rollouts/) inside a pre-existing EKS cluster.

## Usage

```bash
module "argocd" {
  source = "git::https://github.com/DNXLabs/terraform-aws-eks-argocd.git?ref=0.1.0"

  enabled = true
}
```

[See more examples of usage.](https://github.com/DNXLabs/terraform-aws-eks-argocd/tree/master/examples)

#### Login

The initial password is autogenerated with the pod name of the ArgoCD API server:
```bash
ARGO_PWD=`kubectl -n argocd get secret argocd-initial-admin-secret -o jsonpath="{.data.password}" | base64 -d`
```

In order to access the Argo CD server URL, we are going to use the kubectl port-forward command to access the application.
```bash
kubectl port-forward --address 0.0.0.0 -n argocd service/argo-cd-argocd-server 8001:443
```

export ARGOCD_SERVER=`kubectl get svc argocd-server -n argocd -o json | jq --raw-output .status.loadBalancer.ingress[0].hostname`

Using admin as login and the autogenerated password:
```bash
argocd login localhost:8001 --username admin --password $ARGO_PWD --insecure
```

You should get as an output:
```bash
'admin' logged in successfully
```

<!--- BEGIN_TF_DOCS --->

## Requirements

| Name | Version |
|------|---------|
| terraform | >= 0.13 |
| aws | >= 3.13, < 4.0 |
| helm | >= 1.0, < 3.0 |
| kubernetes | >= 1.10.0, < 3.0.0 |

## Providers

| Name | Version |
|------|---------|
| helm | >= 1.0, < 3.0 |
| kubernetes | >= 1.10.0, < 3.0.0 |

## Inputs

| Name | Description | Type | Default | Required |
|------|-------------|------|---------|:--------:|
| create\_namespace | Whether to create Kubernetes namespace with name defined by `namespace`. | `bool` | `true` | no |
| enabled | Variable indicating whether deployment is enabled. | `bool` | `true` | no |
| helm\_chart\_repo | Argo CD repository name. | `string` | `"https://argoproj.github.io/argo-helm"` | no |
| helm\_services | n/a | `list` | <pre>[<br>  {<br>    "chart_version": "3.2.3",<br>    "name": "argo-cd",<br>    "release_name": "argo-cd",<br>    "settings": {}<br>  },<br>  {<br>    "chart_version": "0.5.2",<br>    "name": "argo-rollouts",<br>    "release_name": "argo-rollouts",<br>    "settings": {}<br>  }<br>]</pre> | no |
| mod\_dependency | Dependence variable binds all AWS resources allocated by this module, dependent modules reference this variable. | `any` | `null` | no |
| namespace | Kubernetes namespace to deploy Argo CD Helm chart. | `string` | `"argocd"` | no |
| settings | Additional settings which will be passed to the Helm chart values. | `map` | `{}` | no |

## Outputs

No output.

<!--- END_TF_DOCS --->

## Authors

Module managed by [DNX Solutions](https://github.com/DNXLabs).

## License

Apache 2 Licensed. See [LICENSE](https://github.com/DNXLabs/terraform-aws-eks-argocd/blob/master/LICENSE) for full details.
